@@ -1,8 +1,8 @@
 from mmanager.mmanager import Model
-secret_key = '9cb2825b932f33e40556de3dfd415c0f395503e5'
+secret_key = '0fc94b1d5b7d916d143c070f29bccc1614977c2d'
 url = 'http://localhost:8000'
 model_data = {
-    "project": 46, #Project ID or Usecase ID
+    "project": 71, #Project ID or Usecase ID
     "transformerType": "Classification", #Options: Classification, Regression, Forcasting
     "training_dataset": "",
     "test_dataset": "",
@@ -16,8 +16,8 @@ model_data = {
 ml_options = {
     "credPath": "config.json", #Path to Azure ML credential files.
     "datasetinsertionType": "AzureML", #Option: AzureML, Manual
-    "fetchOption": ["Model"], #To fetch model, add ["Model", "Dataset"] to fetch both model and datasets.
-    "modelName": "histo", #Fetch model file registered with model name.
-    "dataPath": "dataset-name", #Get datasets registered with dataset name.
+    "fetchOption": ["Model", "Dataset"], #To fetch model, add ["Model", "Dataset"] to fetch both model and datasets.
+    "modelName": "model_18_2022_05_31_203641", #Fetch model file registered with model name.
+    "dataPath": "dataset_18_2022_02_13_223137", #Get datasets registered with dataset name.
     }
 Model(secret_key, url).post_model(model_data, ml_options)
\ No newline at end of file
